phonesrv_plat/string_parser_api/inc/CPhoneGsmParserBase.h
branchRCL_3
changeset 20 987c9837762f
parent 19 7d48bed6ce0c
--- a/phonesrv_plat/string_parser_api/inc/CPhoneGsmParserBase.h	Tue Aug 31 15:45:17 2010 +0300
+++ b/phonesrv_plat/string_parser_api/inc/CPhoneGsmParserBase.h	Wed Sep 01 12:15:03 2010 +0100
@@ -70,7 +70,7 @@
 const TUint32 KPhoneGsmUidDialPhoneNumber = 3;
 
 /**
 * Misc GSM required strings, most notably USSD.
 */
 const TUint32 KPhoneGsmUidMisc = 4;
 
@@ -104,6 +104,8 @@
 */
 const TUint32 KPhoneUidUnstructuredService = 
     PHONE_MAKE_UID( KPhoneGsmUidMisc, 0 );
+const TUint32 KPhoneUidIMEI =
+    PHONE_MAKE_UID( KPhoneGsmUidMisc, 1 );
 
 // FORWARD DECLARATIONS
 class CPhoneGsmParserResult;
@@ -70,7 +70,7 @@
 
 /**
-* Misc GSM required strings, most notably USSD.
+* Misc GSM required strings, most notably USSD and IMEI.
 */
 const TUint32 KPhoneGsmUidMisc = 4;